--- title: Project name here keywords: fastai sidebar: home_sidebar summary: "Summary description here." description: "Summary description here." nb_path: "index.ipynb" ---
{% raw %}
{% endraw %}

This file will become your README and also the index of your documentation.

## Install

`pip install your_project_name`

## How to use

Fill me in please! Don't forget code examples:

{% raw %}

    1+1

    2

{% endraw %}